==> ejc-middlemeasurement-impl-3.0.0-20220412.090131-33-sources.jar: com/ejianc/business/middlemeasurement/bean/DesignsubcontractnodedetailEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 设计分包节点报量申请子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_middlemeasurement_designsubcontractnodedetail")
public class DesignsubcontractnodedetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="complete_content")
    private java.lang.String completeContent; // 完成内容
    @TableField(value="measuring_unit")
    private java.lang.String measuringUnit; // 计量单位
    @TableField(value="complete_this_declare")
    private java.math.BigDecimal completeThisDeclare; // 完成量（本期申报）
    @TableField(value="ex_tax_unit_this_declare")
    private java.math.BigDecimal exTaxUnitThisDeclare; // 除税单价（本期申报）
    @TableField(value="in_tax_unit_this_declare")
    private java.math.BigDecimal inTaxUnitThisDeclare; // 含税单价（本期申报）
    @TableField(value="ex_tax_total_this_declare")
    private java.math.BigDecimal exTaxTotalThisDeclare; // 含税合价（本期申报）
    @TableField(value="in_tax_total_this_declare")
    private java.math.BigDecimal inTaxTotalThisDeclare; // 含税合价（本期申报）
    @TableField(value="complete_last_audit")
    private java.math.BigDecimal completeLastAudit; // 完成量（上期累计审核）
    @TableField(value="ex_tax_unit_last_audit")
    private java.math.BigDecimal exTaxUnitLastAudit; // 除税单价（上期累计审核）
    @TableField(value="in_tax_unit_last_audit")
    private java.math.BigDecimal inTaxUnitLastAudit; // 含税单价（上期累计审核）
    @TableField(value="ex_tax_total_last_audit")
    private java.math.BigDecimal exTaxTotalLastAudit; // 含税合价（上期累计审核）
    @TableField(value="in_tax_total_last_audit")
    private java.math.BigDecimal inTaxTotalLastAudit; // 含税合价（上期累计审核）
    @TableField(value="complete_this_audit")
    private java.math.BigDecimal completeThisAudit; // 完成量（本期审核）
    @TableField(value="ex_tax_unit_this_audit")
    private java.math.BigDecimal exTaxUnitThisAudit; // 除税单价（本期审核）
    @TableField(value="in_tax_unit_this_audit")
    private java.math.BigDecimal inTaxUnitThisAudit; // 含税单价（本期审核）
    @TableField(value="ex_tax_total_this_audit")
    private java.math.BigDecimal exTaxTotalThisAudit; // 含税合价（本期审核）
    @TableField(value="in_tax_total_this_audit")
    private java.math.BigDecimal inTaxTotalThisAudit; // 含税合价（本期审核）
    @TableField(value="complete_cumulative_audit")
    private java.math.BigDecimal completeCumulativeAudit; // 完成量（累计审核）
    @TableField(value="ex_tax_unit_cumulative_audit")
    private java.math.BigDecimal exTaxUnitCumulativeAudit; // 除税单价（累计审核）
    @TableField(value="in_tax_unit_cumulative_audit")
    private java.math.BigDecimal inTaxUnitCumulativeAudit; // 含税单价（累计审核）
    @TableField(value="ex_tax_total_cumulative_audit")
    private java.math.BigDecimal exTaxTotalCumulativeAudit; // 含税合价（累计审核）
    @TableField(value="in_tax_total_cumulative_audit")
    private java.math.BigDecimal inTaxTotalCumulativeAudit; // 含税合价（累计审核）
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    
    
    

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 完成内容
     */
    public java.lang.String getCompleteContent() {
        return completeContent;
    }

    /**
     * 完成内容
     */
    public void setCompleteContent(java.lang.String completeContent) {
        this.completeContent = completeContent;
    }
    /**
     * 计量单位
     */
    public java.lang.String getMeasuringUnit() {
        return measuringUnit;
    }

    /**
     * 计量单位
     */
    public void setMeasuringUnit(java.lang.String measuringUnit) {
        this.measuringUnit = measuringUnit;
    }
    /**
     * 完成量（本期申报）
     */
    public java.math.BigDecimal getCompleteThisDeclare() {
        return completeThisDeclare;
    }

    /**
     * 完成量（本期申报）
     */
    public void setCompleteThisDeclare(java.math.BigDecimal completeThisDeclare) {
        this.completeThisDeclare = completeThisDeclare;
    }
    /**
     * 除税单价（本期申报）
     */
    public java.math.BigDecimal getExTaxUnitThisDeclare() {
        return exTaxUnitThisDeclare;
    }

    /**
     * 除税单价（本期申报）
     */
    public void setExTaxUnitThisDeclare(java.math.BigDecimal exTaxUnitThisDeclare) {
        this.exTaxUnitThisDeclare = exTaxUnitThisDeclare;
    }
    /**
     * 含税单价（本期申报）
     */
    public java.math.BigDecimal getInTaxUnitThisDeclare() {
        return inTaxUnitThisDeclare;
    }

    /**
     * 含税单价（本期申报）
     */
    public void setInTaxUnitThisDeclare(java.math.BigDecimal inTaxUnitThisDeclare) {
        this.inTaxUnitThisDeclare = inTaxUnitThisDeclare;
    }
    /**
     * 含税合价（本期申报）
     */
    public java.math.BigDecimal getExTaxTotalThisDeclare() {
        return exTaxTotalThisDeclare;
    }

    /**
     * 含税合价（本期申报）
     */
    public void setExTaxTotalThisDeclare(java.math.BigDecimal exTaxTotalThisDeclare) {
        this.exTaxTotalThisDeclare = exTaxTotalThisDeclare;
    }
    /**
     * 含税合价（本期申报）
     */
    public java.math.BigDecimal getInTaxTotalThisDeclare() {
        return inTaxTotalThisDeclare;
    }

    /**
     * 含税合价（本期申报）
     */
    public void setInTaxTotalThisDeclare(java.math.BigDecimal inTaxTotalThisDeclare) {
        this.inTaxTotalThisDeclare = inTaxTotalThisDeclare;
    }
    /**
     * 完成量（上期累计审核）
     */
    public java.math.BigDecimal getCompleteLastAudit() {
        return completeLastAudit;
    }

    /**
     * 完成量（上期累计审核）
     */
    public void setCompleteLastAudit(java.math.BigDecimal completeLastAudit) {
        this.completeLastAudit = completeLastAudit;
    }
    /**
     * 除税单价（上期累计审核）
     */
    public java.math.BigDecimal getExTaxUnitLastAudit() {
        return exTaxUnitLastAudit;
    }

    /**
     * 除税单价（上期累计审核）
     */
    public void setExTaxUnitLastAudit(java.math.BigDecimal exTaxUnitLastAudit) {
        this.exTaxUnitLastAudit = exTaxUnitLastAudit;
    }
    /**
     * 含税单价（上期累计审核）
     */
    public java.math.BigDecimal getInTaxUnitLastAudit() {
        return inTaxUnitLastAudit;
    }

    /**
     * 含税单价（上期累计审核）
     */
    public void setInTaxUnitLastAudit(java.math.BigDecimal inTaxUnitLastAudit) {
        this.inTaxUnitLastAudit = inTaxUnitLastAudit;
    }
    /**
     * 含税合价（上期累计审核）
     */
    public java.math.BigDecimal getExTaxTotalLastAudit() {
        return exTaxTotalLastAudit;
    }

    /**
     * 含税合价（上期累计审核）
     */
    public void setExTaxTotalLastAudit(java.math.BigDecimal exTaxTotalLastAudit) {
        this.exTaxTotalLastAudit = exTaxTotalLastAudit;
    }
    /**
     * 含税合价（上期累计审核）
     */
    public java.math.BigDecimal getInTaxTotalLastAudit() {
        return inTaxTotalLastAudit;
    }

    /**
     * 含税合价（上期累计审核）
     */
    public void setInTaxTotalLastAudit(java.math.BigDecimal inTaxTotalLastAudit) {
        this.inTaxTotalLastAudit = inTaxTotalLastAudit;
    }
    /**
     * 完成量（本期审核）
     */
    public java.math.BigDecimal getCompleteThisAudit() {
        return completeThisAudit;
    }

    /**
     * 完成量（本期审核）
     */
    public void setCompleteThisAudit(java.math.BigDecimal completeThisAudit) {
        this.completeThisAudit = completeThisAudit;
    }
    /**
     * 除税单价（本期审核）
     */
    public java.math.BigDecimal getExTaxUnitThisAudit() {
        return exTaxUnitThisAudit;
    }

    /**
     * 除税单价（本期审核）
     */
    public void setExTaxUnitThisAudit(java.math.BigDecimal exTaxUnitThisAudit) {
        this.exTaxUnitThisAudit = exTaxUnitThisAudit;
    }
    /**
     * 含税单价（本期审核）
     */
    public java.math.BigDecimal getInTaxUnitThisAudit() {
        return inTaxUnitThisAudit;
    }

    /**
     * 含税单价（本期审核）
     */
    public void setInTaxUnitThisAudit(java.math.BigDecimal inTaxUnitThisAudit) {
        this.inTaxUnitThisAudit = inTaxUnitThisAudit;
    }
    /**
     * 含税合价（本期审核）
     */
    public java.math.BigDecimal getExTaxTotalThisAudit() {
        return exTaxTotalThisAudit;
    }

    /**
     * 含税合价（本期审核）
     */
    public void setExTaxTotalThisAudit(java.math.BigDecimal exTaxTotalThisAudit) {
        this.exTaxTotalThisAudit = exTaxTotalThisAudit;
    }
    /**
     * 含税合价（本期审核）
     */
    public java.math.BigDecimal getInTaxTotalThisAudit() {
        return inTaxTotalThisAudit;
    }

    /**
     * 含税合价（本期审核）
     */
    public void setInTaxTotalThisAudit(java.math.BigDecimal inTaxTotalThisAudit) {
        this.inTaxTotalThisAudit = inTaxTotalThisAudit;
    }
    /**
     * 完成量（累计审核）
     */
    public java.math.BigDecimal getCompleteCumulativeAudit() {
        return completeCumulativeAudit;
    }

    /**
     * 完成量（累计审核）
     */
    public void setCompleteCumulativeAudit(java.math.BigDecimal completeCumulativeAudit) {
        this.completeCumulativeAudit = completeCumulativeAudit;
    }
    /**
     * 除税单价（累计审核）
     */
    public java.math.BigDecimal getExTaxUnitCumulativeAudit() {
        return exTaxUnitCumulativeAudit;
    }

    /**
     * 除税单价（累计审核）
     */
    public void setExTaxUnitCumulativeAudit(java.math.BigDecimal exTaxUnitCumulativeAudit) {
        this.exTaxUnitCumulativeAudit = exTaxUnitCumulativeAudit;
    }
    /**
     * 含税单价（累计审核）
     */
    public java.math.BigDecimal getInTaxUnitCumulativeAudit() {
        return inTaxUnitCumulativeAudit;
    }

    /**
     * 含税单价（累计审核）
     */
    public void setInTaxUnitCumulativeAudit(java.math.BigDecimal inTaxUnitCumulativeAudit) {
        this.inTaxUnitCumulativeAudit = inTaxUnitCumulativeAudit;
    }
    /**
     * 含税合价（累计审核）
     */
    public java.math.BigDecimal getExTaxTotalCumulativeAudit() {
        return exTaxTotalCumulativeAudit;
    }

    /**
     * 含税合价（累计审核）
     */
    public void setExTaxTotalCumulativeAudit(java.math.BigDecimal exTaxTotalCumulativeAudit) {
        this.exTaxTotalCumulativeAudit = exTaxTotalCumulativeAudit;
    }
    /**
     * 含税合价（累计审核）
     */
    public java.math.BigDecimal getInTaxTotalCumulativeAudit() {
        return inTaxTotalCumulativeAudit;
    }

    /**
     * 含税合价（累计审核）
     */
    public void setInTaxTotalCumulativeAudit(java.math.BigDecimal inTaxTotalCumulativeAudit) {
        this.inTaxTotalCumulativeAudit = inTaxTotalCumulativeAudit;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    
}

==> ejc-middlemeasurement-impl-3.0.0-20221219.062630-293-sources.jar: com/ejianc/business/middlemeasurement/bean/DesignsubcontractnodedetailEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 设计分包节点报量申请子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_middlemeasurement_designsubcontractnodedetail")
public class DesignsubcontractnodedetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="complete_content")
    private java.lang.String completeContent; // 完成内容
    @TableField(value="measuring_unit")
    private java.lang.String measuringUnit; // 计量单位
    @TableField(value="complete_this_declare")
    private java.math.BigDecimal completeThisDeclare; // 完成量（本期申报）
    @TableField(value="ex_tax_unit_this_declare")
    private java.math.BigDecimal exTaxUnitThisDeclare; // 除税单价（本期申报）
    @TableField(value="in_tax_unit_this_declare")
    private java.math.BigDecimal inTaxUnitThisDeclare; // 含税单价（本期申报）
    @TableField(value="ex_tax_total_this_declare")
    private java.math.BigDecimal exTaxTotalThisDeclare; // 含税合价（本期申报）
    @TableField(value="in_tax_total_this_declare")
    private java.math.BigDecimal inTaxTotalThisDeclare; // 含税合价（本期申报）
    @TableField(value="complete_last_audit")
    private java.math.BigDecimal completeLastAudit; // 完成量（上期累计审核）
    @TableField(value="ex_tax_unit_last_audit")
    private java.math.BigDecimal exTaxUnitLastAudit; // 除税单价（上期累计审核）
    @TableField(value="in_tax_unit_last_audit")
    private java.math.BigDecimal inTaxUnitLastAudit; // 含税单价（上期累计审核）
    @TableField(value="ex_tax_total_last_audit")
    private java.math.BigDecimal exTaxTotalLastAudit; // 含税合价（上期累计审核）
    @TableField(value="in_tax_total_last_audit")
    private java.math.BigDecimal inTaxTotalLastAudit; // 含税合价（上期累计审核）
    @TableField(value="complete_this_audit")
    private java.math.BigDecimal completeThisAudit; // 完成量（本期审核）
    @TableField(value="ex_tax_unit_this_audit")
    private java.math.BigDecimal exTaxUnitThisAudit; // 除税单价（本期审核）
    @TableField(value="in_tax_unit_this_audit")
    private java.math.BigDecimal inTaxUnitThisAudit; // 含税单价（本期审核）
    @TableField(value="ex_tax_total_this_audit")
    private java.math.BigDecimal exTaxTotalThisAudit; // 含税合价（本期审核）
    @TableField(value="in_tax_total_this_audit")
    private java.math.BigDecimal inTaxTotalThisAudit; // 含税合价（本期审核）
    @TableField(value="complete_cumulative_audit")
    private java.math.BigDecimal completeCumulativeAudit; // 完成量（累计审核）
    @TableField(value="ex_tax_unit_cumulative_audit")
    private java.math.BigDecimal exTaxUnitCumulativeAudit; // 除税单价（累计审核）
    @TableField(value="in_tax_unit_cumulative_audit")
    private java.math.BigDecimal inTaxUnitCumulativeAudit; // 含税单价（累计审核）
    @TableField(value="ex_tax_total_cumulative_audit")
    private java.math.BigDecimal exTaxTotalCumulativeAudit; // 含税合价（累计审核）
    @TableField(value="in_tax_total_cumulative_audit")
    private java.math.BigDecimal inTaxTotalCumulativeAudit; // 含税合价（累计审核）
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value = "contract")
    private java.lang.Long contract;


    public Long getContract() {
        return contract;
    }

    public void setContract(Long contract) {
        this.contract = contract;
    }

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 完成内容
     */
    public java.lang.String getCompleteContent() {
        return completeContent;
    }

    /**
     * 完成内容
     */
    public void setCompleteContent(java.lang.String completeContent) {
        this.completeContent = completeContent;
    }
    /**
     * 计量单位
     */
    public java.lang.String getMeasuringUnit() {
        return measuringUnit;
    }

    /**
     * 计量单位
     */
    public void setMeasuringUnit(java.lang.String measuringUnit) {
        this.measuringUnit = measuringUnit;
    }
    /**
     * 完成量（本期申报）
     */
    public java.math.BigDecimal getCompleteThisDeclare() {
        return completeThisDeclare;
    }

    /**
     * 完成量（本期申报）
     */
    public void setCompleteThisDeclare(java.math.BigDecimal completeThisDeclare) {
        this.completeThisDeclare = completeThisDeclare;
    }
    /**
     * 除税单价（本期申报）
     */
    public java.math.BigDecimal getExTaxUnitThisDeclare() {
        return exTaxUnitThisDeclare;
    }

    /**
     * 除税单价（本期申报）
     */
    public void setExTaxUnitThisDeclare(java.math.BigDecimal exTaxUnitThisDeclare) {
        this.exTaxUnitThisDeclare = exTaxUnitThisDeclare;
    }
    /**
     * 含税单价（本期申报）
     */
    public java.math.BigDecimal getInTaxUnitThisDeclare() {
        return inTaxUnitThisDeclare;
    }

    /**
     * 含税单价（本期申报）
     */
    public void setInTaxUnitThisDeclare(java.math.BigDecimal inTaxUnitThisDeclare) {
        this.inTaxUnitThisDeclare = inTaxUnitThisDeclare;
    }
    /**
     * 含税合价（本期申报）
     */
    public java.math.BigDecimal getExTaxTotalThisDeclare() {
        return exTaxTotalThisDeclare;
    }

    /**
     * 含税合价（本期申报）
     */
    public void setExTaxTotalThisDeclare(java.math.BigDecimal exTaxTotalThisDeclare) {
        this.exTaxTotalThisDeclare = exTaxTotalThisDeclare;
    }
    /**
     * 含税合价（本期申报）
     */
    public java.math.BigDecimal getInTaxTotalThisDeclare() {
        return inTaxTotalThisDeclare;
    }

    /**
     * 含税合价（本期申报）
     */
    public void setInTaxTotalThisDeclare(java.math.BigDecimal inTaxTotalThisDeclare) {
        this.inTaxTotalThisDeclare = inTaxTotalThisDeclare;
    }
    /**
     * 完成量（上期累计审核）
     */
    public java.math.BigDecimal getCompleteLastAudit() {
        return completeLastAudit;
    }

    /**
     * 完成量（上期累计审核）
     */
    public void setCompleteLastAudit(java.math.BigDecimal completeLastAudit) {
        this.completeLastAudit = completeLastAudit;
    }
    /**
     * 除税单价（上期累计审核）
     */
    public java.math.BigDecimal getExTaxUnitLastAudit() {
        return exTaxUnitLastAudit;
    }

    /**
     * 除税单价（上期累计审核）
     */
    public void setExTaxUnitLastAudit(java.math.BigDecimal exTaxUnitLastAudit) {
        this.exTaxUnitLastAudit = exTaxUnitLastAudit;
    }
    /**
     * 含税单价（上期累计审核）
     */
    public java.math.BigDecimal getInTaxUnitLastAudit() {
        return inTaxUnitLastAudit;
    }

    /**
     * 含税单价（上期累计审核）
     */
    public void setInTaxUnitLastAudit(java.math.BigDecimal inTaxUnitLastAudit) {
        this.inTaxUnitLastAudit = inTaxUnitLastAudit;
    }
    /**
     * 含税合价（上期累计审核）
     */
    public java.math.BigDecimal getExTaxTotalLastAudit() {
        return exTaxTotalLastAudit;
    }

    /**
     * 含税合价（上期累计审核）
     */
    public void setExTaxTotalLastAudit(java.math.BigDecimal exTaxTotalLastAudit) {
        this.exTaxTotalLastAudit = exTaxTotalLastAudit;
    }
    /**
     * 含税合价（上期累计审核）
     */
    public java.math.BigDecimal getInTaxTotalLastAudit() {
        return inTaxTotalLastAudit;
    }

    /**
     * 含税合价（上期累计审核）
     */
    public void setInTaxTotalLastAudit(java.math.BigDecimal inTaxTotalLastAudit) {
        this.inTaxTotalLastAudit = inTaxTotalLastAudit;
    }
    /**
     * 完成量（本期审核）
     */
    public java.math.BigDecimal getCompleteThisAudit() {
        return completeThisAudit;
    }

    /**
     * 完成量（本期审核）
     */
    public void setCompleteThisAudit(java.math.BigDecimal completeThisAudit) {
        this.completeThisAudit = completeThisAudit;
    }
    /**
     * 除税单价（本期审核）
     */
    public java.math.BigDecimal getExTaxUnitThisAudit() {
        return exTaxUnitThisAudit;
    }

    /**
     * 除税单价（本期审核）
     */
    public void setExTaxUnitThisAudit(java.math.BigDecimal exTaxUnitThisAudit) {
        this.exTaxUnitThisAudit = exTaxUnitThisAudit;
    }
    /**
     * 含税单价（本期审核）
     */
    public java.math.BigDecimal getInTaxUnitThisAudit() {
        return inTaxUnitThisAudit;
    }

    /**
     * 含税单价（本期审核）
     */
    public void setInTaxUnitThisAudit(java.math.BigDecimal inTaxUnitThisAudit) {
        this.inTaxUnitThisAudit = inTaxUnitThisAudit;
    }
    /**
     * 含税合价（本期审核）
     */
    public java.math.BigDecimal getExTaxTotalThisAudit() {
        return exTaxTotalThisAudit;
    }

    /**
     * 含税合价（本期审核）
     */
    public void setExTaxTotalThisAudit(java.math.BigDecimal exTaxTotalThisAudit) {
        this.exTaxTotalThisAudit = exTaxTotalThisAudit;
    }
    /**
     * 含税合价（本期审核）
     */
    public java.math.BigDecimal getInTaxTotalThisAudit() {
        return inTaxTotalThisAudit;
    }

    /**
     * 含税合价（本期审核）
     */
    public void setInTaxTotalThisAudit(java.math.BigDecimal inTaxTotalThisAudit) {
        this.inTaxTotalThisAudit = inTaxTotalThisAudit;
    }
    /**
     * 完成量（累计审核）
     */
    public java.math.BigDecimal getCompleteCumulativeAudit() {
        return completeCumulativeAudit;
    }

    /**
     * 完成量（累计审核）
     */
    public void setCompleteCumulativeAudit(java.math.BigDecimal completeCumulativeAudit) {
        this.completeCumulativeAudit = completeCumulativeAudit;
    }
    /**
     * 除税单价（累计审核）
     */
    public java.math.BigDecimal getExTaxUnitCumulativeAudit() {
        return exTaxUnitCumulativeAudit;
    }

    /**
     * 除税单价（累计审核）
     */
    public void setExTaxUnitCumulativeAudit(java.math.BigDecimal exTaxUnitCumulativeAudit) {
        this.exTaxUnitCumulativeAudit = exTaxUnitCumulativeAudit;
    }
    /**
     * 含税单价（累计审核）
     */
    public java.math.BigDecimal getInTaxUnitCumulativeAudit() {
        return inTaxUnitCumulativeAudit;
    }

    /**
     * 含税单价（累计审核）
     */
    public void setInTaxUnitCumulativeAudit(java.math.BigDecimal inTaxUnitCumulativeAudit) {
        this.inTaxUnitCumulativeAudit = inTaxUnitCumulativeAudit;
    }
    /**
     * 含税合价（累计审核）
     */
    public java.math.BigDecimal getExTaxTotalCumulativeAudit() {
        return exTaxTotalCumulativeAudit;
    }

    /**
     * 含税合价（累计审核）
     */
    public void setExTaxTotalCumulativeAudit(java.math.BigDecimal exTaxTotalCumulativeAudit) {
        this.exTaxTotalCumulativeAudit = exTaxTotalCumulativeAudit;
    }
    /**
     * 含税合价（累计审核）
     */
    public java.math.BigDecimal getInTaxTotalCumulativeAudit() {
        return inTaxTotalCumulativeAudit;
    }

    /**
     * 含税合价（累计审核）
     */
    public void setInTaxTotalCumulativeAudit(java.math.BigDecimal inTaxTotalCumulativeAudit) {
        this.inTaxTotalCumulativeAudit = inTaxTotalCumulativeAudit;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    
}
